@@ -27,7 +27,7 @@ class OP(_OPCommandInterface):
     """
 
     def __init__(self, vault=None, account_shorthand=None, signin_address=None, email_address=None,
-                 secret_key=None, password=None, logger=None, op_path='op'):
+                 secret_key=None, password=None, logger=None, op_path='op', use_existing_session=False, password_prompt=True):
         """
         Create an OP object. The 1Password sign-in happens during object instantiation.
         If 'password' is not provided, the 'op' command will prompt on the console for a password.
@@ -49,9 +49,15 @@ class OP(_OPCommandInterface):
             - 'password': The user's master password
             - 'logger': A logging object. If not provided a basic logger is created and used.
             - 'op_path': optional path to the `op` command, if it's not at the default location
+            - 'use_existing_session': A boolean indicating whether an existing login session should be used if possible
+            - 'password_prompt': A boolean indicating whether an interactive password prompt on the console should be presented if necessary
 
         Raises:
             - OPSigninException if 1Password sign-in fails for any reason.
+            - OPNotSignedInException if:
+                - No session is available for reuse (or session reuse not requested), and
+                - no password provided, and
+                - interactive password prompt is supressed
             - OPNotFoundException if the 1Password command can't be found.
         """
         super().__init__(vault=vault,
@@ -61,7 +67,9 @@ class OP(_OPCommandInterface):
                          secret_key=secret_key,
                          password=password,
                          logger=logger,
-                         op_path=op_path)
+                         op_path=op_path,
+                         use_existing_session=use_existing_session,
+                         password_prompt=password_prompt)
 
     def _get_abstract(self, abstract_obj_type: str, abs_name_or_uuid: str, exception_on_err: OPCmdFailedException):
         lookup_argv = [self.op_path, "get",
@@ -205,7 +213,7 @@ class OP(_OPCommandInterface):
             raise OPForgetException.from_opexception(ocfe) from ocfe
 
     def _sanitize(self):
-        self.token = None
+        self._token = None
         sess_var_name = 'OP_SESSION_{}'.format(self.account_shorthand)
         try:
             env.pop(sess_var_name)
@@ -226,17 +234,6 @@ class OP(_OPCommandInterface):
         Returns:
             - Value of the specified field to lookup
         """
-        # lookup_argv = [self.op_path, "get", "item", item_name_or_uuid]
-        # output = self._run_lookup(lookup_argv, self.token, decode="utf-8")
-        # item = json.loads(output)
-        # details = item['details']
-        # fields = details['fields']
-        # value = None
-        # for field in fields:
-        #     if 'designation' not in field.keys():
-        #         continue
-        #     if field['designation'] == field_designation:
-        #         value = field['value']
         item: OPAbstractItem
         if field_designation == "password":
             value = self.get_item_password(item_name_or_uuid)
